# CARE-SM Toolkit
**Repository dedicated to CARE-SM Toolkit**

<p align="center"> 
    <img src="https://github.com/CARE-SM/CARE-SM-docs/blob/main/docs/assets/care-sm.png?raw=true"width="300" height="300"> 
<p align="center" > </p> 

## Documentation

Learn more about our documentation for this toolkit [here](https://care-sm.readthedocs.io/en/latest/toolkit.html).

## Communication and feedback
Your feedback is more than welcome. It will help us improve our semantic data model. Please use [github issues](https://github.com/CARE-SM/CARE-SM-Toolkit/issues) to provide your feedback.